import 'dart:io';
import 'package:file/local.dart';
import 'package:shell/shell.dart';
import 'generate_i18n.dart';

const constant = {
  "FLUTTER": "flutter/bin",
  "CACHED": ".pub-cache/hosted/pub.dartlang.org",
  "PERFIX": "package:tencent_cloud_chat_sdk",
  "NAME": "tencent_im_base-"
};

void main(List<String> arguments) async {
  stdout
      .write("Welcome to Tencent Cloud Chat language customization tool.\n\n");

  stdout.write("A. Get Original language template.\n");
  stdout.write(
      "B. Adding your customized language JSON to Tencent Cloud Chat.\n");
  stdout.write("Please choose: (A/B)");
  final option = stdin.readLineSync();

  switch (option) {
    case "A":
    case "a":
      getOriginalLanguage();
      break;
    case "B":
    case "b":
      addLanguageToBase();
      // getOriginalLanguage("Chinese");
      break;
  }

  // stdout.write(name);
}

void addLanguageToBase() async {
  final shell = Shell();
  final flutterPath = getFlutterEnvPath();
  final packagePath = await getCachedTencentPath(flutterPath);
  final baseI18NPath = "$packagePath/lib/i18n/";

  final customLanguageDir = Directory("languages");
  final List<FileSystemEntity> files = customLanguageDir.listSync();
  List<String> filePaths = files.map((e) => e.path).toList();
  for (var value in filePaths) {
    final fileName = value.split("/").last;
    shell.run("cp", arguments: [value, "$baseI18NPath$fileName"]);
  }

  generateTranslationDartFile(baseI18NPath);
}

void getOriginalLanguage() async {
  final shell = Shell();
  const fs = LocalFileSystem();

  final flutterPath = getFlutterEnvPath();
  final packagePath = await getCachedTencentPath(flutterPath);
  final languageDirectory = Directory("$packagePath/lib/i18n");
  final templates = languageDirectory.listSync();
  final List<String> templatesPath = templates.map((e) => e.path).toList();

  if(!(fs.isDirectorySync("languages"))){
    Directory("languages").create();
  }

  for (var element in templatesPath) {
    final fileName = element.split("/").last;
    if(fileName.contains(".i18n.json")){
      shell.run("cp", arguments: [element, "languages/$fileName"]);
    }
  }

  stdout.write("\nTemplates have been stored to: languages/ \n");
}

String getFlutterEnvPath() {
  String flutterPath = "";
  final path = Platform.environment['PATH'];
  List<String> paths = path?.split(':') ?? [];
  for (String currentPath in paths) {
    if (currentPath.contains(constant["FLUTTER"]!)) {
      flutterPath = currentPath;
      break;
    }
  }
  return flutterPath;
}

Future<String> getCachedTencentPath(String flutterPath) async {
  List<String> versions = [];
  final cachePath =
      "${flutterPath.replaceAll("bin", "")}${constant["CACHED"]}";
  final paths = getAllDir(cachePath);
  for (String element in paths) {
    if (element.contains(constant["NAME"]!)) {
      versions.add(element);
    }
  }
  versions.sort((a, b) => versionCompare(
      a.split(constant["NAME"]!)[1], b.split(constant["NAME"]!)[1]));
  return versions.last;
}

List<String> getAllDir(String path) {
  const fs = LocalFileSystem();
  final directory = fs.directory(path);
  final List<FileSystemEntity> files = directory.listSync();
  List<String> paths = files.map((e) => e.path).toList();
  return paths;
}

int versionCompare(String firstVersion, String secondVersion) {
  int v1Number = getExtendedVersionNumber(firstVersion); // return 10020003
  int v2Number = getExtendedVersionNumber(secondVersion); // return 10020011
  return (v1Number >= v2Number) ? 1 : 0;
}

int getExtendedVersionNumber(String version) {
  List versionCells = version.split('.');
  versionCells = versionCells.map((i) => int.parse(i)).toList();
  return versionCells[0] * 100000 + versionCells[1] * 1000 + versionCells[2];
}
